/**
 * Execute a phantomjs script.
 * @memberof apeman-util/lib/browsing
 * @function execPhantomScript
 * @param {string} filename - Script file name to execute.
 * @param {string[]} args - Args.
 * @param {callback} callback - Callback when done.
 * @author Taka Okunishi
 */

"use strict";

var core = require('../core'),
    ext = require('../ext'),
    file = require('../file'),
    async = ext.async,
    childProcess = core.childProcess;

/** @lends execPhantomScript */
function execPhantomScript(filename, args, callback) {
    async.waterfall([
        function (callback) {
            execPhantomScript._lookupPhantomjs(callback);
        },
        function (phantomjs, callback) {
            args = [].concat(filename).concat(args);
            execPhantomScript._spawn(phantomjs.path, args, callback);
        }
    ], callback);
};

execPhantomScript._lookupPhantomjs = function (callback) {
    async.waterfall([
        function (callback) {
            var pattern = 'node_modules/phantomjs';
            file.lookupFile(pattern, __dirname, function (err, dirname) {
                if (err) {
                    //Try from current working directory.
                    file.lookupFile(pattern, process.cwd(), callback);
                } else {
                    callback(null, dirname);
                }
            });
        },
        function (dirname, callback) {
            try {
                var phantomjs = require(dirname);
                callback(null, phantomjs);
            } catch (e) {
                var err = new Error('phantomjs is required. try `npm install phantomjs`.');
                callback(err)
                return;
            }
        },
    ], callback);
}

execPhantomScript._spawn = function (bin, args, callback) {
    var spawned = childProcess.spawn(bin, args);
    spawned.stdout.pipe(process.stdout);
    spawned.stderr.pipe(process.stderr);
    spawned.on('exit', function () {
        callback();
    });
}


module.exports = execPhantomScript;
