/**
 * Run process persistently.
 * @memberof module:apeman/util/clustering
 * @function persist
 * @param {object} cluster - Node cluster.
 * @param {object} config - Persist configuration.
 * @param {string} config.basedir - Base directory path.
 * @param {function} config.start - Callback for start.
 * @param {function} config.stop - Callback for stop.
 * @param {function} config.workerStart - Callback for workerStart.
 * @param {function} config.workerStop - Callback for workerStop.
 *
 */


"use strict";

var PersistForker = require('./persist_forker');

/** @lends persist */
function persist(cluster, config) {

    if (config.wokerStart) {
        console.log('Do not use "config.wokerStart". Since this is a just miss spelling for "config.workerStart" in apeman-util@0.0.40. And will be removed in next update.');
        config.workerStart = config.wokerStart;
    }

    var forker = new PersistForker(config.basedir);
    if (cluster.isMaster) {

        forker.on('fork', function (pid) {
            console.log('\tWorker start with pid:', pid);
        });

        forker.on('unfork', function (pid) {
            console.error('Worker dead:', pid);
        });

        forker.on('refork', function (pid) {
            console.log('Restart worker:', pid);
        });

        forker.on('start', config.start);
        forker.on('stop', config.stop);

        forker.bindMaster(cluster, process);
    } else {
        forker.on('start', config.workerStart);
        forker.on('stop', config.workerStop);
        forker.bindWorker(cluster, process);
    }
}

persist.kill = function (basedir, callback) {
    var forker = new PersistForker(basedir);
    forker.kill(callback);
};


module.exports = persist;