/**
 * @file Lookup a file.
 * @memberof module:apeman-util/lib/file
 * @function lookupFile
 * @param {string} filename - Filename to lookup.
 * @param {string} [basedir=process.cwd()] - Base directory name to lookup with.
 * @param {function} callback - Callback when done.
 * @author Taka Okunishi
 */


"use strict";

var u = require('../../lib'),
    core = u.core,
    fs = core.fs,
    path = core.path;

/** @lends lookupFile */
module.exports = function lookupFile(filename, basedir, callback) {
    var s = this,
        resolved = path.resolve(basedir || '.', filename);
    fs.exists(resolved, function (exists) {
        if (exists) {
            callback(null, resolved);
        } else {
            var parentDir = path.dirname(basedir);
            var notFound = basedir === parentDir;
            if (notFound) {
                callback(new Error('File not found: ' + filename));
            } else {
                lookupFile(filename, parentDir, callback);
            }
        }
    });
};