/**
 * @file Relative symlink.
 * @memberof module:apeman-util/lib/file
 * @function relativeSymlink
 * @param {string} src - Source file (actual file) path.
 * @param {string} dest - Destination file (link) path.
 * @param {function} callback - Callback when done.
 * @see {@link module:apeman-util|util}
 * @author Taka Okunishi
 */

"use strict";


var u = require('../../lib'),
    core = u.core,
    fs = core.fs,
    path = core.path;

module.exports = function relativeSymlink(src, dest, callback) {
    try {
        var destDir = path.dirname(path.resolve(dest)),
            cwd = process.cwd();

        while (exports._isSymlinkSync(src)) {
            src = path.join(path.dirname(src), fs.readlinkSync(src));
        }

        var srcName = path.relative(destDir, src),
            destName = path.relative(destDir, dest);

        process.chdir(destDir);
        if (fs.existsSync(destName)) {
            exports._rm(destName);
        }
        fs.symlinkSync(srcName, destName);
        process.chdir(cwd);
        callback(null);
    } catch (e) {
        callback(e);
    }
};

/**
 * Remove a file (or symlink or directory.)
 * @param {string} filename - Filename to remove.
 * @private
 */
exports._rm = function (filename) {
    var isDir = exports._isDirSync(filename) && !exports._isSymlinkSync(filename),
        rm = isDir ? fs.rmdirSync : fs.unlinkSync;
    rm(filename);
};


/**
 * Is a dir or not.
 * @param {string} filename
 * @returns {boolean}
 * @private
 */
exports._isDirSync = function (filename) {
    return fs.statSync(filename).isDirectory();
};

/**
 * Is a symlink or not.
 * @param {string} filename
 * @returns {boolean}
 * @private
 */
exports._isSymlinkSync = function (filename) {
    return fs.lstatSync(filename).isSymbolicLink();
};



