/**
 * Watch files by pattern.
 * @see http://nodejs.org/api/fs.html#fs_fs_watch_filename_options_listener
 * @memberof module:apeman-util/lib/file
 * @function watchAll
 * @param {string|string[]} filenames - Glob file name patterns to watch.
 * @param {object} [options] - Optional settings.
 * @param {function} listner - Listner functions.
 * @author Taka Okunishi
 */

"use strict";

var u = require('../../lib'),
    fs = u.core.fs,
    async = u.ext.async,
    reducing = u.reducing,
    glob = u.ext.glob;

function watch(filename, options, listener) {
    if (!fs.existsSync(filename)) {
        return null;
    }
    var watcher = fs.watch(filename, options, function (event) {
        if (listener) {
            listener(event, filename);
        }
        if (event === 'rename') {
            var newWtacher = watch(filename, options, listener);
            watcher.close();
            if (newWtacher) {
                watcher.close = function () {
                    newWtacher.close();
                }
            }
        }
    });
    return watcher;
}

/** @lends watchAll */
module.exports = function watchAll(filenames, options, listener) {
    filenames = [].concat(filenames)
        .map(function (filename) {
            return glob.sync(filename);
        })
        .reduce(reducing.concatReduce(), []);

    return  filenames
        .map(function (filename) {
            return watch(filename, options, listener);
        })
        .filter(function (watcher) {
            return !!watcher;
        });
}