/**
 * Write a readonly file.
 * @memberof module:apeman-util/lib/file
 * @function writeReadonlyFile
 * @param {string} filename - Filename to write.
 * @param {string|buffer} content - Content to write.
 * @param {function} callback - Callback when done.
 * @see {@link module:apeman-util|util}
 * @author Taka Okunishi
 */

"use strict";

var u = require('../../lib'),
    ext = u.ext,
    core = u.core,
    fs = core.fs,
    async = ext.async;

module.exports = function writeReadonlyFile(filename, content, callback) {
    async.series([
        function (callback) {
            fs.exists(filename, function (exists) {
                if (exists) {
                    fs.chmod(filename, '644', callback);
                } else {
                    callback(null);
                }
            })
        },
        function (callback) {
            fs.writeFile(filename, content, callback);
        },
        function (callback) {
            fs.chmod(filename, '444', callback);
        }
    ], callback);
};