/**
 * Create base 64 string.
 * @memberof module:apeman-util/lib/imaging
 * @function base64String
 * @param {Buffer} buffer - Image buffer data.
 * @param {string} type - Image type
 * @example
 *      console.log(base64String(buffer, 'png'));
 */

"use strict";

var u = require('../../lib'),
    async = u.ext.async,
    fs = u.core.fs,
    path = u.core.path,
format = u.core.util.format;

/** @lends base64String */
function base64String(buffer, type) {
    var prefix = 'image';
    if (type) {
        prefix = [prefix, type].join('/');
    }
    return format("data:%s;base64, %s", prefix, new Buffer(buffer).toString('base64'));
}

/**
 * @memgerof module:apeman-util/lib/imaging
 * @function base64String.fromFile
 * @param {string} filename - Filename to read.
 * @param {function} callback - Callback when done.
 */
base64String.fromFile = function (filename, callback) {
    async.waterfall([
        function (callback) {
            fs.readFile(filename, callback);
        },
        function (buffer, callback) {
            var extname = path.extname(filename);
            callback(null, base64String(buffer, extname.replace(/^\./, '')));
        }
    ], callback);
}

module.exports = base64String;

