/**
 * @file Read json file.
 * @memberof module:json
 * @function readJsonFile
 * @param {string} filename - Filename to read.
 * @param {function} callback - Callback when done.
 * @see {@link module:apeman-util|util}
 * @author Taka Okunishi
 */

"use strict";

var u = require('../../lib'),
    ext = u.ext,
    core = u.core,
    fs = core.fs,
    async = ext.async;

module.exports = function readJsonFile(filename, callback) {
    fs.exists(filename, function (exists) {
        if (!exists) {
            callback(null, null);
            return null;
        }
        async.waterfall([
            function (callback) {
                fs.readFile(filename, callback);
            },
            function (buffer, callback) {
                try {
                    var data = JSON.parse(buffer.toString());
                    callback(null, data);
                } catch (e) {
                    callback(null, null);
                }
            }
        ], callback);
    });
};