/**
 * @file Diff.
 * @memberof module:apeman-util/lib/object
 * @function Diff
 * @param {object} older - Older object.
 * @param {object} newer - Newer object.
 * @author Taka Okunishi
 */

"use strict";

/** @lends Diff */
function Diff() {
    var s = this;
    s.initialize.apply(s, arguments);
}

/**
 * Initialize the diff object.
 * @param older
 * @param newer
 */
Diff.prototype.initialize = function (older, newer) {
    var s = this;
    var properties = Object.keys(older).concat(Object.keys(newer));
    properties
        .forEach(function (key) {
            var isChanged = older[key] != newer[key];
            s[key] = isChanged ? [older[key], newer[key]] : null;
        });

};

/**
 * Get new properties.
 * @returns {object}
 */
Diff.prototype.newer = function () {
    var s = this,
        result = {};
    Object.keys(s).forEach(function (key) {
        var values = s[key];
        if (values && values.length) {
            result[key] = values[1];
        }
    });
    return result;
};


module.exports = Diff;