/**
 * Inject mock functions to node modules.
 * @memberof module:apeman-util/lib/testing
 * @constructor MockInjector
 * @see {@link module:apeman-util|util}
 * @author Taka Okunishi
 */

"use strict";

/** @lends MockInjector */
function MockInjector() {
    var s = this;
    s.stack = [];
}

/**
 * Inject a mock to a module.
 * @param {object} module - Module to injected.
 * @param {string} key - Injection key.
 * @param {*} injection - Mock property to inject.
 */

MockInjector.prototype.inject = function (module, key, injection) {
    var s = this;
    s.stack.push({
        module: module,
        key: key,
        origin: module[key],
        injection: injection
    });
    module[key] = injection;
};

/**
 * Pop injected.
 * @protected
 * @returns {*} - Injected object.
 */
MockInjector.prototype._popInjected = function () {
    var s = this;
    return s.stack.pop();
};

/**
 * Restore injected.
 */
MockInjector.prototype.restoreInjected = function () {
    var s = this;
    var data = s._popInjected();
    if (data) {
        data.module[data.key] = data.origin;
    }
};

/**
 * Restore all injected.
 */
MockInjector.prototype.restoreAllInjected = function () {
    var s = this;
    while (s.stack.length) {
        s.restoreInjected();
    }
};

module.exports = MockInjector;