/**
 * @file Test for cluster_helper.js.
 * Runs with node unit.
 */

"use strict";

var ClusterHelper = require('./../../lib/clustering/cluster_helper.js'),
    h = require('../_helper'),
    fs = h.fs;

exports.setUp = function (done) {
    // h.injector.inject(console, 'log', h.doNothing);
    done();
};

exports.tearDown = function (done) {
    h.injector.restoreAllInjected();
    done();
};

exports.setUp = function (done) {
    h.injector.inject(console, 'log', h.doNothing);
    h.injector.inject(console, 'error', h.doNothing);
    done();
};

exports.tearDown = function (done) {
    h.injector.restoreAllInjected();
    done();
};

exports['Create a helper.'] = function (test) {
    var helper = new ClusterHelper;
    test.ok(helper);
    test.ok(helper.async);
    test.ok(helper.persist);
    test.done();
};

exports['Kill a process.'] = function (test) {
    var helper = new ClusterHelper;
    helper.kill([], '__invalid_pid__', function (err) {
        test.ok(err);
        test.done();
    });
};

exports['Cluster helper.'] = function (test) {
    var basedir = h.prepareCleanWorkDirForTestFile(__filename);
    var helper = new ClusterHelper(basedir);
    test.ok(helper);
    test.ok(helper.numberOfCPUs());
    test.ok(helper.statusFilename());
    test.done();
};

exports['Access status file.'] = function (test) {
    var basedir = h.prepareCleanWorkDirForTestFile(__filename),
        helper = new ClusterHelper(basedir);
    helper.writeStatus({
        foo: 'bar'
    }, function (err) {
        test.ifError(err);
        helper.readStatus(function (err, data) {
            test.ifError(err);
            test.equal(data.foo, 'bar');
            fs.unlinkSync(helper.statusFilename());
            helper.readStatus(function (err, data) {
                test.ifError(err);
                test.done();
            });
        });
    });
};


exports['Fork a file.'] = function (test) {
    var bin = h.resolveMockFile('mock_bin.js');
    var basedir = h.prepareCleanWorkDirForTestFile(__filename),
        helper = new ClusterHelper(basedir);
    helper.fork(bin, [], function (err) {
        test.ifError(err);
        test.done();
    });
};

exports['Done.'] = function (test) {
    test.ok(new ClusterHelper().done("foo"));
    test.done();
};