/**
 * @file Test for form_validator.js.
 * Runs with node unit.
 */

"use strict";

var FormValidator = require('./../../lib/form/form_validator.js'),
    h = require('../_helper');

exports.setUp = function (done) {
    // h.injector.inject(console, 'log', h.doNothing);
    done();
};

exports.tearDown = function (done) {
    h.injector.restoreAllInjected();
    done();
};

exports['Form validator.'] = function (test) {
    var formValidator = new FormValidator({});
    formValidator.addSchema('foo', {
        type: 'object',
        properties: {
            firstname: {
                type: 'string',
                minLength: 2,
                maxLength: 15
            },
            lastname: {
                type: 'string',
                minLength: 2,
                maxLength: 25
            },
            gender: {
                type: 'string',
                enum: ['male', 'female']
            },
            email: {
                type: 'string',
                format: 'email'
            },
            password: {
                type: 'string',
                minLength: 8
            }
        },
        required: ['firstname', 'lastname', 'email', 'password']
    });
    formValidator.addLocale('ja', {
        properties: {
            firstname: '名',
            email: 'Eメール'
        },
        errors: {
            required: '{property}は必須です。',
            minLength: '{property}は{minLength}文字以上で入力してください。',
            maxLength: '{property}は{minLength}文字以下で入力してください。',
            enum: '{property}は{enum}のいずれかにしてください。'
        }
    });
    formValidator.setLang('ja');
    var error = formValidator.validate('foo', {
        lastname: 'TooLongTooLongTooLongTooLongTooLongTooLongTooLongTooLongTooLong',
        gender: 'foo',
        password: '2'
    });
    test.deepEqual(error.firstname, {reason: {required: true}, message: ['名は必須です。']});
    test.deepEqual(error.email, {reason: {required: true}, message: ['Eメールは必須です。']});
    test.deepEqual(error.password, {
        reason: {minLength: true},
        message: ['passwordは8文字以上で入力してください。']
    });
    test.deepEqual(error.lastname, {
        reason: {maxLength: true},
        message: ['lastnameは2文字以下で入力してください。']
    });
    test.done();
};

exports['Add schema.'] = function(test){
    var formValidator = new FormValidator({});
    formValidator.addSchema({
        foo:{
            type: 'object'
        }
    });
    test.done();
};